@@ -1,4 +1,4 @@
-# Author: Robert J. Hijmans, r.hijmans@gmail.com
+# Author: Robert J. Hijmans
 # Date :  June 2008
 # Version 0.9
 # Licence GPL v3
@@ -13,14 +13,18 @@ setMethod('cover', signature(x='RasterLayer', y='RasterLayer'),
 	function(x, y, ..., filename=''){ 
 	
 	rasters <- .makeRasterList(x, y, ...)
+	if (length(rasters) == 1) {
+		return(rasters[[1]])
+	}
+	compareRaster(rasters)
+	
 	nl <- sapply(rasters, nlayers)
 	if (max(nl) > 1) {
 		stop("Only single layer (RasterLayer) objects can be used if 'x' and 'y' have a single layer")
 	} 
 		
 	outRaster <- raster(x)
-	compareRaster(c(outRaster, rasters))
-	
+		
 	filename <- trim(filename)
 	dots <- list(...)
 	if (is.null(dots$format))  { 
