@@ -38,39 +38,51 @@
 
 .distm <- function (x, longlat) {
 	if (longlat) { 
-		fun <- .haversine 
+		n <- nrow(x)
+		dm <- matrix(ncol = n, nrow = n)
+		dm[cbind(1:n, 1:n)] <- 0
+		if (n > 1) {
+			for (i in 2:n) {
+				j = 1:(i - 1)
+				dm[i, j] = .geodist(x[i, 1], x[i, 2], x[j, 1], x[j, 2])
+			}
+		}
+		return(dm)
 	} else { 
 		return(.planedist2(x, x))
-	#	fun <- .planedist
 	}
-    n = nrow(x)
-    dm = matrix(ncol = n, nrow = n)
-    dm[cbind(1:n, 1:n)] = 0
-    if (n == 1) {
-        return(dm)
-    }
-    for (i in 2:n) {
-        j = 1:(i - 1)
-        dm[i, j] = fun(x[i, 1], x[i, 2], x[j, 1], x[j, 2])
-    }
-    return(dm)
 }
 
 
 .distm2 <- function (x, y, longlat) {
 	if (longlat) { 
-		fun <- .haversine 
+		n <- nrow(x)
+		m <- nrow(y)
+		dm <- matrix(ncol=m, nrow=n)
+		for (i in 1:n) {
+			dm[i,] <- .geodist(x[i, 1], x[i, 2], y[, 1], y[, 2])
+		}
+		return(dm)
 	} else { 
 		return(.planedist2(x, y))
 		# fun <- .planedist
 	}
-	n = nrow(x)
-	m = nrow(y)
-	dm = matrix(ncol=m, nrow=n)
-	for (i in 1:n) {
-		dm[i,] = fun(x[i, 1], x[i, 2], y[, 1], y[, 2])
+}
+
+.distm2new <- function (x, y, longlat, a=6378137, f=1/298.257223563) {
+	if (longlat) { 
+		n <- nrow(x)
+		m <- nrow(y)
+		
+		xx <- cbind(rep(x[,1], m), rep(x[,2], m))
+		yy <- cbind(rep(y[,1], each=n), rep(y[,2], each=n))
+		
+		g <- .Call("_raster_point_distance", xx, yy, TRUE, a, f, PACKAGE='raster')
+		return(matrix(g, n, m))
+	} else { 
+		return(.planedist2(x, y))
+		# fun <- .planedist
 	}
-	return(dm)
 }
 
 
@@ -80,8 +92,15 @@ pointDistance <- function (p1, p2, lonlat, allpairs=FALSE, ...) {
 	if (!is.null(longlat)) {
 		lonlat <- longlat
 	}
+
 	if (missing(lonlat)) {
-		stop('you must provide a "lonlat" argument (TRUE/FALSE)')
+		if (isLonLat(p1)) {
+			lonlat <- TRUE
+		} else if (! is.na(projection(p1)) ) {
+			lonlat <- FALSE		
+		} else {
+			stop('you must provide a "lonlat" argument (TRUE/FALSE)')
+		}
 	}
 	stopifnot(is.logical(lonlat)) 
 	
@@ -103,7 +122,8 @@ pointDistance <- function (p1, p2, lonlat, allpairs=FALSE, ...) {
 	}
 	
 	if (lonlat ) {
-		return( .haversine(p1[,1], p1[,2], p2[,1], p2[,2], r=6378137) )
+#		return( .haversine(p1[,1], p1[,2], p2[,1], p2[,2], r=6378137) )
+		return( .geodist(p1[,1], p1[,2], p2[,1], p2[,2]) )
 	} else { 
 		return( .planedist(p1[,1], p1[,2], p2[,1], p2[,2]) )
 	}
@@ -115,7 +135,7 @@ pointDistance <- function (p1, p2, lonlat, allpairs=FALSE, ...) {
 
 
 .planedist2 <- function(p1, p2) {
-# code by Bill Venables, CSIRO Laboratories
+# code by Bill Venables
 # https://stat.ethz.ch/pipermail/r-help/2008-February/153841.html
 	z0 <- complex(, p1[,1], p1[,2])
 	z1 <- complex(, p2[,1], p2[,2])
@@ -123,8 +143,15 @@ pointDistance <- function (p1, p2, lonlat, allpairs=FALSE, ...) {
 }
 
 
+.geodist <- function(x1, y1, x2, y2, a=6378137, f=1/298.257223563) {
+	# recycle
+    p <- cbind(x1, y1, x2, y2)
+	.Call("_raster_point_distance", p[,1:2, drop=FALSE], p[, 3:4,drop=FALSE], TRUE, a, f, PACKAGE='raster')
+#	.Call("inversegeodesic", as.double(p[,1]), as.double(p[,2]), as.double(p[,3]), as.double(p[,4]), as.double(a), as.double(f), PACKAGE='raster')
+}
 
-.haversine <- function(x1, y1, x2, y2, r=6378137) {
+
+.old_haversine <- function(x1, y1, x2, y2, r=6378137) {
 	adj <- pi / 180
 	x1 <- x1 * adj
 	y1 <- y1 * adj
