@@ -5,10 +5,6 @@
 
 
 
-if (!isGeneric("crs")) {
-	setGeneric("crs", function(x, ...)
-		standardGeneric("crs"))
-}	
 
 setMethod("crs", signature('ANY'), 
 	function(x, asText=FALSE, ...) {
@@ -51,7 +47,6 @@ setMethod('as.character', signature(x='CRS'),
 			}
 		}
 	} 
-	
 	if (inherits(x, 'Spatial')) {
 		x@proj4string <- crs
 	} else {
@@ -65,10 +60,12 @@ setMethod('as.character', signature(x='CRS'),
 
 projection <- function(x, asText=TRUE) {
 
-	if (extends(class(x), "BasicRaster")) { 
+	if (methods::extends(class(x), "BasicRaster")) { 
 		x <- x@crs 
-	} else if (extends(class(x), "Spatial")) { 
+	} else if (methods::extends(class(x), "Spatial")) { 
 		x <- x@proj4string
+	} else if (methods::extends(class(x), "sf")) {
+		return( attr(x$geometry, 'crs')$proj4string )
 	} else if (class(x) == 'character') { 
 		if (asText) {
 			return(x)
